translate.convert.xliff2po

Package translate :: Package convert :: Module xliff2po |
[hide private]
[frames] | no frames]

# Module xliff2po

source code

Convert XLIFF localization files to Gettext PO localization files.

see: http://translate.sourceforge.net/wiki/toolkit/xliff2po for examples and usage instructions.

Classes | [hide private]
| xliff2po

Functions | [hide private]
convertxliff(inputfile, outputfile, templates) reads in stdin using fromfileclass, converts using convertorclass, writes to stdout | source code
main(argv=None) | source code

Imports: po, xliff, wStringIO